@@ -2,6 +2,10 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=invalid-name
 
+import os
+import sys
+import platform
+
 # Constants
 Fs = 10000  # Sampling rate of the simulated data [Hz]
 WORKER_DAQ_INTERVAL_MS = 10  # [ms]
@@ -17,8 +21,6 @@ BENCH_LOG_FILE = "log.txt"
 
 # Mechanism to support both PyQt and PySide
 # -----------------------------------------
-import os
-import sys
 
 PYQT5 = "PyQt5"
 PYQT6 = "PyQt6"
@@ -36,7 +38,6 @@ if len(sys.argv) > 1:
             QT_LIB = lib
             break
 
-# pylint: disable=import-error, no-name-in-module, c-extension-no-member
 if QT_LIB is None:
     for lib in QT_LIB_ORDER:
         if lib in sys.modules:
@@ -54,12 +55,13 @@ if QT_LIB is None:
 
 if QT_LIB is None:
     this_file = __file__.split(os.sep)[-1]
-    raise Exception(
+    raise ImportError(
         f"{this_file} requires PyQt5, PyQt6, PySide2 or PySide6; "
         "none of these packages could be imported."
     )
 
 # fmt: off
+# pylint: disable=import-error, no-name-in-module
 if QT_LIB == PYQT5:
     from PyQt5 import QtCore, QtWidgets as QtWid           # type: ignore
     from PyQt5.QtCore import pyqtSlot as Slot              # type: ignore
@@ -72,17 +74,18 @@ elif QT_LIB == PYSIDE2:
 elif QT_LIB == PYSIDE6:
     from PySide6 import QtCore, QtWidgets as QtWid         # type: ignore
     from PySide6.QtCore import Slot                        # type: ignore
+# pylint: enable=import-error, no-name-in-module
 # fmt: on
 
+# pylint: disable=c-extension-no-member
 QT_VERSION = (
     QtCore.QT_VERSION_STR if QT_LIB in (PYQT5, PYQT6) else QtCore.__version__
 )
+# pylint: enable=c-extension-no-member
 
-# pylint: enable=import-error, no-name-in-module, c-extension-no-member
 # \end[Mechanism to support both PyQt and PySide]
 # -----------------------------------------------
 
-import platform
 import psutil
 import GPUtil
 import numpy as np
