@@ -71,9 +71,11 @@ Usage:
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-pyqtgraph-threadsafe"
-__date__ = "13-10-2022"
+__date__ = "28-10-2022"
 __version__ = "3.2.6"
 
+import os
+import sys
 from functools import partial
 from typing import Union, Tuple, List, Optional
 
@@ -84,8 +86,6 @@ except:  # pylint: disable=bare-except
 
 # Mechanism to support both PyQt and PySide
 # -----------------------------------------
-import os
-import sys
 
 PYQT5 = "PyQt5"
 PYQT6 = "PyQt6"
@@ -94,7 +94,6 @@ PYSIDE6 = "PySide6"
 QT_LIB_ORDER = [PYQT5, PYSIDE2, PYSIDE6, PYQT6]
 QT_LIB = os.getenv("PYQTGRAPH_QT_LIB")
 
-# pylint: disable=import-error, no-name-in-module, c-extension-no-member
 if QT_LIB is None:
     for lib in QT_LIB_ORDER:
         if lib in sys.modules:
@@ -112,12 +111,13 @@ if QT_LIB is None:
 
 if QT_LIB is None:
     this_file = __file__.split(os.sep)[-1]
-    raise Exception(
+    raise ImportError(
         f"{this_file} requires PyQt5, PyQt6, PySide2 or PySide6; "
         "none of these packages could be imported."
     )
 
 # fmt: off
+# pylint: disable=import-error, no-name-in-module
 if QT_LIB == PYQT5:
     from PyQt5 import QtCore, QtGui, QtWidgets as QtWid    # type: ignore
     from PyQt5.QtCore import pyqtSlot as Slot              # type: ignore
@@ -130,9 +130,9 @@ elif QT_LIB == PYSIDE2:
 elif QT_LIB == PYSIDE6:
     from PySide6 import QtCore, QtGui, QtWidgets as QtWid  # type: ignore
     from PySide6.QtCore import Slot                        # type: ignore
+# pylint: enable=import-error, no-name-in-module
 # fmt: on
 
-# pylint: enable=import-error, no-name-in-module, c-extension-no-member
 # \end[Mechanism to support both PyQt and PySide]
 # -----------------------------------------------
 
